@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2017,2019-2022 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019-2023 Aurimas Cernius
  * Copyright (C) 2009, 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -36,7 +36,6 @@
 #include "debug.hpp"
 #include "iactionmanager.hpp"
 #include "ignote.hpp"
-#include "preferencetabaddin.hpp"
 #include "watchers.hpp"
 #include "notebooks/notebookapplicationaddin.hpp"
 #include "notebooks/notebooknoteaddin.hpp"
@@ -48,9 +47,8 @@
 namespace gnote {
 
 #define REGISTER_BUILTIN_NOTE_ADDIN(klass) \
-  do { sharp::IfaceFactoryBase *iface = new sharp::IfaceFactory<klass>; \
-  m_builtin_ifaces.push_back(iface); \
-  m_note_addin_infos.insert(std::make_pair(typeid(klass).name(),iface)); } while(0)
+  do { m_builtin_ifaces.push_back(std::make_unique<sharp::IfaceFactory<klass>>()); \
+  m_note_addin_infos.insert(std::make_pair(typeid(klass).name(), m_builtin_ifaces.back().get())); } while(0)
 
 #define REGISTER_APP_ADDIN(klass) \
   m_app_addins.insert(std::make_pair(typeid(klass).name(),        \
@@ -59,9 +57,8 @@ namespace gnote {
 #define SETUP_NOTE_ADDIN(key, klass) \
   m_preferences.signal_##key##_changed.connect([this]() { \
     if(m_preferences.key()) { \
-      sharp::IfaceFactoryBase *iface = new sharp::IfaceFactory<klass>; \
-      m_builtin_ifaces.push_back(iface); \
-      load_note_addin(typeid(klass).name(), iface); \
+      m_builtin_ifaces.push_back(std::make_unique<sharp::IfaceFactory<klass>>()); \
+      load_note_addin(typeid(klass).name(), m_builtin_ifaces.back().get()); \
     } \
     else { \
       erase_note_addin_info(typeid(klass).name()); \
@@ -91,12 +88,12 @@ namespace gnote {
 
 namespace {
   template <typename AddinType>
-  Glib::ustring get_id_for_addin(const AbstractAddin & addin, const std::map<Glib::ustring, AddinType*> & addins)
+  Glib::ustring get_id_for_addin(const AbstractAddin & addin, const std::map<Glib::ustring, std::unique_ptr<AddinType>> & addins)
   {
     const AddinType *plugin = dynamic_cast<const AddinType*>(&addin);
     if(plugin != NULL) {
-      for(auto iter : addins) {
-        if(iter.second == plugin) {
+      for(const auto & iter : addins) {
+        if(iter.second.get() == plugin) {
           return iter.first;
         }
       }
@@ -127,16 +124,6 @@ namespace {
 
   AddinManager::~AddinManager()
   {
-    sharp::map_delete_all_second(m_app_addins);
-    for(NoteAddinMap::const_iterator iter = m_note_addins.begin();
-        iter != m_note_addins.end(); ++iter) {
-      sharp::map_delete_all_second(iter->second);
-    }
-    sharp::map_delete_all_second(m_addin_prefs);
-    sharp::map_delete_all_second(m_import_addins);
-    for(auto iter : m_builtin_ifaces) {
-      delete iter;
-    }
   }
 
   void AddinManager::add_note_addin_info(Glib::ustring && id, const sharp::DynamicModule * dmod)
@@ -170,12 +157,13 @@ namespace {
         continue;
       }
 
-      const Note::Ptr & note = iter->first;
-      NoteAddin *const addin = dynamic_cast<NoteAddin *>((*f)());
-      if(addin) {
-       addin->initialize(m_gnote, note);
-       id_addin_map.insert(std::make_pair(std::move(id), addin));
-      }
+      m_note_manager.find_by_uri(iter->first, [this, id=std::move(id), f, &id_addin_map](NoteBase & note) {
+        NoteAddin *const addin = dynamic_cast<NoteAddin*>((*f)());
+        if(addin) {
+          addin->initialize(m_gnote, std::static_pointer_cast<Note>(note.shared_from_this()));
+          id_addin_map.insert(std::make_pair(std::move(id), addin));
+        }
+      });
     }
   }
 
@@ -201,12 +189,8 @@ namespace {
           continue;
         }
 
-        NoteAddin * const addin = it->second;
-        if (addin) {
-          addin->dispose(true);
-          delete addin;
-          id_addin_map.erase(it);
-        }
+        it->second->dispose(true);
+        id_addin_map.erase(it);
       }
     }
   }
@@ -246,17 +230,17 @@ namespace {
   {
     std::vector<Glib::ustring> addins;
     bool global_addins_prefs_loaded = true;
-    Glib::KeyFile global_addins_prefs;
+    auto global_addins_prefs = Glib::KeyFile::create();
     try {
-      global_addins_prefs.load_from_file(m_addins_prefs_file);
+      global_addins_prefs->load_from_file(m_addins_prefs_file);
     }
     catch(Glib::Error & not_loaded) {
       global_addins_prefs_loaded = false;
     }
 
     for(AddinInfoMap::const_iterator iter = m_addin_infos.begin(); iter != m_addin_infos.end(); ++iter) {
-      if(global_addins_prefs_loaded && global_addins_prefs.has_key("Enabled", iter->first)) {
-        if(global_addins_prefs.get_boolean("Enabled", iter->first)) {
+      if(global_addins_prefs_loaded && global_addins_prefs->has_key("Enabled", iter->first)) {
+        if(global_addins_prefs->get_boolean("Enabled", iter->first)) {
           addins.push_back(iter->second.addin_module());
         }
       }
@@ -360,16 +344,15 @@ namespace {
     return AddinInfo();
   }
 
-  void AddinManager::load_addins_for_note(const Note::Ptr & note)
+  void AddinManager::load_addins_for_note(NoteBase & note)
   {
-    if(m_note_addins.find(note) != m_note_addins.end()) {
+    auto & uri = note.uri();
+    if(m_note_addins.find(uri) != m_note_addins.end()) {
       ERR_OUT(_("Trying to load addins when they are already loaded"));
       return;
     }
-    IdAddinMap loaded_addins;
-    m_note_addins[note] = loaded_addins;
 
-    IdAddinMap & loaded(m_note_addins[note]); // avoid copying the whole map
+    IdAddinMap & loaded(m_note_addins[uri]); // avoid copying the whole map
     for(IdInfoMap::const_iterator iter = m_note_addin_infos.begin();
         iter != m_note_addin_infos.end(); ++iter) {
 
@@ -377,7 +360,7 @@ namespace {
       sharp::IInterface* iface = (*addin_info.second)();
       NoteAddin * addin = dynamic_cast<NoteAddin *>(iface);
       if(addin) {
-        addin->initialize(m_gnote, note);
+        addin->initialize(m_gnote, std::static_pointer_cast<Note>(note.shared_from_this()));
         loaded.insert(std::make_pair(addin_info.first, addin));
       }
       else {
@@ -387,13 +370,13 @@ namespace {
     }
   }
 
-  std::vector<NoteAddin*> AddinManager::get_note_addins(const Note::Ptr & note) const
+  std::vector<NoteAddin*> AddinManager::get_note_addins(const NoteBase & note) const
   {
     std::vector<NoteAddin*> addins;
-    NoteAddinMap::const_iterator iter = m_note_addins.find(note);
+    NoteAddinMap::const_iterator iter = m_note_addins.find(note.uri());
     if(iter != m_note_addins.end()) {
       for(IdAddinMap::const_iterator it = iter->second.begin(); it != iter->second.end(); ++it) {
-        addins.push_back(it->second);
+        addins.push_back(it->second.get());
       }
     }
 
@@ -407,13 +390,13 @@ namespace {
       = m_import_addins.find(id);
 
     if (m_import_addins.end() != import_iter)
-      return import_iter->second;
+      return import_iter->second.get();
 
     const AppAddinMap::const_iterator app_iter
       = m_app_addins.find(id);
 
     if (m_app_addins.end() != app_iter)
-      return app_iter->second;
+      return app_iter->second.get();
 
     return 0;
   }
@@ -422,27 +405,29 @@ namespace {
   {
     const IdSyncServiceAddinMap::const_iterator iter = m_sync_service_addins.find(id);
     if(iter != m_sync_service_addins.end()) {
-      return iter->second;
+      return iter->second.get();
     }
 
     return NULL;
   }
 
-  std::vector<PreferenceTabAddin*> AddinManager::get_preference_tab_addins() const
-  {
-    return sharp::map_get_values(m_pref_tab_addins);
-  }
-
-
   std::vector<sync::SyncServiceAddin*> AddinManager::get_sync_service_addins() const
   {
-    return sharp::map_get_values(m_sync_service_addins);
+    std::vector<sync::SyncServiceAddin*> ret;
+    for(auto & plugin : m_sync_service_addins) {
+      ret.push_back(plugin.second.get());
+    }
+    return ret;
   }
 
 
   std::vector<ImportAddin*> AddinManager::get_import_addins() const
   {
-    return sharp::map_get_values(m_import_addins);
+    std::vector<ImportAddin*> ret;
+    for(auto & plugin : m_import_addins) {
+      ret.push_back(plugin.second.get());
+    }
+    return ret;
   }
 
   void AddinManager::initialize_application_addins() const
@@ -450,11 +435,11 @@ namespace {
     register_addin_actions();
     for(AppAddinMap::const_iterator iter = m_app_addins.begin();
         iter != m_app_addins.end(); ++iter) {
-      ApplicationAddin * addin = iter->second;
+      ApplicationAddin & addin = *iter->second;
       const sharp::DynamicModule * dmod
         = m_module_manager.get_module(iter->first);
       if (!dmod || dmod->is_enabled()) {
-        addin->initialize(m_gnote, m_note_manager);
+        addin.initialize(m_gnote, m_note_manager);
       }
     }
   }
@@ -465,7 +450,7 @@ namespace {
         iter != m_sync_service_addins.end(); ++iter) {
       sync::SyncServiceAddin *addin = NULL;
       try {
-        addin = iter->second;
+        addin = iter->second.get();
         const sharp::DynamicModule *dmod = m_module_manager.get_module(iter->first);
         if(!dmod || dmod->is_enabled()) {
           addin->initialize(m_gnote, m_gnote.sync_manager());
@@ -483,16 +468,16 @@ namespace {
   {
     for(AppAddinMap::const_iterator iter = m_app_addins.begin();
         iter != m_app_addins.end(); ++iter) {
-      ApplicationAddin * addin = iter->second;
+      ApplicationAddin & addin = *iter->second;
       const sharp::DynamicModule * dmod
         = m_module_manager.get_module(iter->first);
       if (!dmod || dmod->is_enabled()) {
         try {
-          addin->shutdown();
+          addin.shutdown();
         }
         catch (const sharp::Exception & e) {
           DBG_OUT("Error calling %s.Shutdown (): %s",
-                  typeid(*addin).name(), e.what());
+                  typeid(addin).name(), e.what());
         }
       }
     }
@@ -500,9 +485,9 @@ namespace {
 
   void AddinManager::save_addins_prefs() const
   {
-    Glib::KeyFile global_addins_prefs;
+    auto global_addins_prefs = Glib::KeyFile::create();
     try {
-      global_addins_prefs.load_from_file(m_addins_prefs_file);
+      global_addins_prefs->load_from_file(m_addins_prefs_file);
     }
     catch (Glib::Error & not_loaded_ignored) {
     }
@@ -513,15 +498,10 @@ namespace {
       const Glib::ustring & mod_id = iter->first;
       sharp::ModuleMap::const_iterator mod_iter = modules.find(iter->second.addin_module());
       bool enabled = mod_iter != modules.end() && mod_iter->second->is_enabled();
-      global_addins_prefs.set_boolean("Enabled", mod_id, enabled);
+      global_addins_prefs->set_boolean("Enabled", mod_id, enabled);
     }
 
-    Glib::RefPtr<Gio::File> prefs_file = Gio::File::create_for_path(
-                                           m_addins_prefs_file);
-    Glib::RefPtr<Gio::FileOutputStream> prefs_file_stream
-                                          = prefs_file->append_to();
-    prefs_file_stream->truncate(0);
-    prefs_file_stream->write(global_addins_prefs.to_data());
+    global_addins_prefs->save_to_file(m_addins_prefs_file);
   }
 
   AddinInfo AddinManager::get_addin_info(const Glib::ustring & id) const
@@ -537,9 +517,6 @@ namespace {
   {
     Glib::ustring id;
     id = get_id_for_addin(addin, m_app_addins);
-    if(id.empty()) {
-      id = get_id_for_addin(addin, m_pref_tab_addins);
-    }
     if(id.empty()) {
       id = get_id_for_addin(addin, m_sync_service_addins);
     }
