@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013 Aurimas Cernius
+ * Copyright (C) 2013,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -26,13 +26,14 @@
 
 #include <gtkmm/widget.h>
 
-#include "base/macros.hpp"
 #include "notemanager.hpp"
 #include "sharp/modulefactory.hpp"
 
 
 namespace gnote {
 
+class IGnote;
+
 
 /** the base class for the preference dialog factory */
 class AddinPreferenceFactoryBase
@@ -40,7 +41,7 @@ class AddinPreferenceFactoryBase
 {
 public:
   static const char * IFACE_NAME;
-  virtual Gtk::Widget * create_preference_widget(NoteManager & m) = 0;
+  virtual Gtk::Widget *create_preference_widget(IGnote & g, Preferences & p, NoteManager & m) = 0;
 };
 
 
@@ -54,9 +55,9 @@ public:
     {
       return new AddinPreferenceFactory<_AddinType>();
     }
-  virtual Gtk::Widget * create_preference_widget(NoteManager & m) override
+  virtual Gtk::Widget *create_preference_widget(IGnote & g, Preferences & p, NoteManager & m) override
     {
-      return Gtk::manage(new _AddinType(m));
+      return Gtk::manage(new _AddinType(g, p, m));
     }
 };
 
