@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013-2014,2016,2019 Aurimas Cernius
+ * Copyright (C) 2013-2014,2016,2019,2022-2023 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,11 +18,14 @@
  */
 
 
+#include "config.h"
+
 #include <giomm/dbusconnection.h>
 #include <giomm/dbuserror.h>
 
-#include <set>
+#include <unordered_set>
 
+#include "base/hash.hpp"
 #include "debug.hpp"
 #include "iconmanager.hpp"
 #include "ignote.hpp"
@@ -70,10 +73,6 @@ void SearchProvider::on_method_call(const Glib::RefPtr<Gio::DBus::Connection> &,
       stub_func func = iter->second;
       invocation->return_value((this->*func)(parameters));
     }
-    catch(Glib::Exception & e) {
-      invocation->return_error(Gio::DBus::Error(Gio::DBus::Error::UNKNOWN_METHOD,
-                               "Exception in method " + method_name + ": " + e.what()));
-    }
     catch(std::exception & e) {
       invocation->return_error(Gio::DBus::Error(Gio::DBus::Error::UNKNOWN_METHOD,
                                "Exception in method " + method_name + ": " + e.what()));
@@ -87,27 +86,22 @@ void SearchProvider::on_method_call(const Glib::RefPtr<Gio::DBus::Connection> &,
 
 std::vector<Glib::ustring> SearchProvider::GetInitialResultSet(const std::vector<Glib::ustring> & terms)
 {
-  std::set<gnote::NoteBase::Ptr> final_result;
+  std::unordered_set<Glib::ustring, gnote::Hash<Glib::ustring>> final_result;
   std::vector<Glib::ustring> search_terms;
   search_terms.reserve(terms.size());
   for(auto & term : terms) {
     search_terms.push_back(term.casefold());
   }
-  for(auto note : m_manager.get_notes()) {
-    auto title = note->get_title().casefold();
+  m_manager.for_each([&final_result, search_terms](gnote::NoteBase & note) {
+    auto title = note.get_title().casefold();
     for(auto term : search_terms) {
       if(title.find(term) != Glib::ustring::npos) {
-        final_result.insert(note);
+        final_result.insert(note.uri());
       }
     }
-  }
+  });
 
-  std::vector<Glib::ustring> ret;
-  for(auto note : final_result) {
-    ret.push_back(note->uri());
-  }
-
-  return ret;
+  return std::vector<Glib::ustring>(final_result.begin(), final_result.end());
 }
 
 Glib::VariantContainerBase SearchProvider::GetInitialResultSet_stub(const Glib::VariantContainerBase & params)
@@ -125,7 +119,7 @@ Glib::VariantContainerBase SearchProvider::GetInitialResultSet_stub(const Glib::
 std::vector<Glib::ustring> SearchProvider::GetSubsearchResultSet(
     const std::vector<Glib::ustring> & previous_results, const std::vector<Glib::ustring> & terms)
 {
-  std::set<Glib::ustring> previous(previous_results.begin(), previous_results.end());
+  std::unordered_set<Glib::ustring, gnote::Hash<Glib::ustring>> previous(previous_results.begin(), previous_results.end());
   if(previous.size() == 0) {
     return std::vector<Glib::ustring>();
   }
@@ -159,15 +153,12 @@ std::vector<std::map<Glib::ustring, Glib::ustring> > SearchProvider::GetResultMe
 {
   std::vector<std::map<Glib::ustring, Glib::ustring> > ret;
   for(std::vector<Glib::ustring>::const_iterator iter = identifiers.begin(); iter != identifiers.end(); ++iter) {
-    gnote::NoteBase::Ptr note = m_manager.find_by_uri(*iter);
-    if(note == 0) {
-      continue;
-    }
-
-    std::map<Glib::ustring, Glib::ustring> meta;
-    meta["id"] = note->uri();
-    meta["name"] = note->get_title();
-    ret.push_back(meta);
+    m_manager.find_by_uri(*iter, [&ret](gnote::NoteBase & note) {
+      std::map<Glib::ustring, Glib::ustring> meta;
+      meta["id"] = note.uri();
+      meta["name"] = note.get_title();
+      ret.push_back(meta);
+    });
   }
 
   return ret;
@@ -203,10 +194,9 @@ void SearchProvider::ActivateResult(const Glib::ustring & identifier,
                                     const std::vector<Glib::ustring> & /*terms*/,
                                     guint32 /*timestamp*/)
 {
-  gnote::NoteBase::Ptr note = m_manager.find_by_uri(identifier);
-  if(note != 0) {
-    m_gnote.open_note(std::static_pointer_cast<gnote::Note>(note));
-  }
+  m_manager.find_by_uri(identifier, [this](gnote::NoteBase & note) {
+    m_gnote.open_note(note);
+  });
 }
 
 Glib::VariantContainerBase SearchProvider::ActivateResult_stub(const Glib::VariantContainerBase & params)
@@ -231,14 +221,9 @@ Glib::VariantContainerBase SearchProvider::LaunchSearch_stub(const Glib::Variant
   return Glib::VariantContainerBase();
 }
 
-gchar *SearchProvider::get_icon()
+const gchar *SearchProvider::get_icon() const
 {
-  if(!m_note_icon) {
-    Gtk::IconInfo info = m_gnote.icon_manager().lookup_icon(gnote::IconManager::NOTE, 48);
-    m_note_icon = Gio::Icon::create(info.get_filename());
-  }
-
-  return g_icon_to_string(m_note_icon->gobj());
+  return DATADIR"/gnote/icons/hicolor/24x24/places/note.png";
 }
 
 
