@@ -30,6 +30,8 @@ namespace gnote {
 class IActionManager
 {
 public:
+  typedef sigc::slot<void(const Glib::VariantBase&)> ActionCallback;
+
   virtual ~IActionManager();
 
   virtual Glib::RefPtr<Gio::SimpleAction> get_app_action(const Glib::ustring & name) const = 0;
@@ -39,12 +41,11 @@ public:
   virtual std::map<Glib::ustring, const Glib::VariantType*> get_main_window_actions() const = 0;
   virtual bool is_modifying_main_window_action(const Glib::ustring & action) const = 0;
 
-  virtual void register_main_window_search_callback(Glib::ustring && id, Glib::ustring && action,
-                                                    sigc::slot<void, const Glib::VariantBase&> callback) = 0;
+  virtual void register_main_window_search_callback(Glib::ustring && id, Glib::ustring && action, const ActionCallback & callback) = 0;
   virtual void unregister_main_window_search_callback(const Glib::ustring & id) = 0;
-  virtual std::map<Glib::ustring, sigc::slot<void, const Glib::VariantBase&>> get_main_window_search_callbacks() = 0;
-  sigc::signal<void> signal_main_window_search_actions_changed;
-  sigc::signal<void, std::vector<PopoverWidget>&> signal_build_main_window_search_popover;
+  virtual std::map<Glib::ustring, ActionCallback> get_main_window_search_callbacks() = 0;
+  sigc::signal<void()> signal_main_window_search_actions_changed;
+  sigc::signal<void(std::vector<PopoverWidget>&)> signal_build_main_window_search_popover;
 };
 
 }
