@@ -1,7 +1,7 @@
  /*
  * gnote
  *
- * Copyright (C) 2010-2017,2019-2023 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -258,7 +258,9 @@ namespace gnote {
     , m_tag_table(NULL)
   {
     for(const auto & iter : m_data.data().tags()) {
-      add_tag(iter.second);
+      if(auto tag = _manager.tag_manager().get_tag(iter)) {
+        add_tag(*tag);
+      }
     }
   }
 
@@ -301,9 +303,11 @@ namespace gnote {
     m_is_deleting = true;
     
     // Remove the note from all the tags
-    for(NoteData::TagMap::const_iterator iter = m_data.data().tags().begin();
-        iter != m_data.data().tags().end(); ++iter) {
-      remove_tag(iter->second);
+    auto thetags = m_data.data().tags();
+    for(const auto &iter : thetags) {
+      if(auto tag = manager().tag_manager().get_tag(iter)) {
+        remove_tag(*tag);
+      }
     }
 
     if (m_window) {
@@ -428,37 +432,6 @@ namespace gnote {
     set_change_type(changeType);
   }
 
-  void Note::remove_tag(Tag & tag)
-  {
-    Glib::ustring tag_name = tag.normalized_name();
-    NoteData::TagMap & thetags(m_data.data().tags());
-    NoteData::TagMap::iterator iter;
-
-    // if we are deleting the note, no need to check for the tag, we 
-    // know it is there.
-    if(!m_is_deleting) {
-      iter = thetags.find(tag_name);
-      if (iter == thetags.end())  {
-        return;
-      }
-    }
-
-    signal_tag_removing(*this, tag);
-
-    // don't erase the tag if we are deleting the note. 
-    // This will invalidate the iterator.
-    // see bug 579839.
-    if(!m_is_deleting) {
-      thetags.erase(iter);
-    }
-    tag.remove_note(*this);
-
-    signal_tag_removed(*this, tag_name);
-
-    DBG_OUT("Tag removed, queueing save");
-    queue_save(OTHER_DATA_CHANGED);
-  }
-
   void Note::add_child_widget(Glib::RefPtr<Gtk::TextChildAnchor> && child_anchor, Gtk::Widget *widget)
   {
     m_child_widget_queue.push(ChildWidgetData(std::move(child_anchor), widget));
