@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2017,2019-2020,2022-2023 Aurimas Cernius
+ * Copyright (C) 2011-2014,2017,2019-2020,2022-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -242,44 +242,52 @@ void NoteBase::delete_note()
 {
   // Remove the note from all the tags
   // remove_tag modifies map, so always iterate from start
-  NoteData::TagMap & thetags(data_synchronizer().data().tags());
-  for(NoteData::TagMap::const_iterator iter = thetags.begin(); iter != thetags.end(); iter = thetags.begin()) {
-    remove_tag(iter->second);
+  auto thetags = data_synchronizer().data().tags();
+  auto &tag_manager = m_manager.tag_manager();
+  for(auto &thetag : thetags) {
+    if(auto tag = tag_manager.get_tag(thetag)) {
+      remove_tag(*tag);
+    }
   }
 }
 
-void NoteBase::add_tag(const Tag::Ptr & tag)
+void NoteBase::add_tag(Tag &tag)
 {
-  if(!tag) {
-    throw sharp::Exception ("note::add_tag() called with a NULL tag.");
+  tag.add_note(*this);
+
+  auto &thetags = data_synchronizer().data().tags();
+  auto tag_name = tag.normalized_name();
+  if(thetags.find(tag_name) != thetags.end()) {
+    return;
   }
-  tag->add_note(*this);
 
-  NoteData::TagMap & thetags(data_synchronizer().data().tags());
-  if(thetags.find(tag->normalized_name()) == thetags.end()) {
-    thetags[tag->normalized_name()] = tag;
+  thetags.insert(tag_name);
 
-    signal_tag_added(*this, tag);
+  signal_tag_added(*this, tag);
 
-    DBG_OUT ("Tag added, queueing save");
-    queue_save(OTHER_DATA_CHANGED);
-  }
+  DBG_OUT ("Tag added, queueing save");
+  queue_save(OTHER_DATA_CHANGED);
 }
 
 void NoteBase::remove_tag(Tag & tag)
 {
   Glib::ustring tag_name = tag.normalized_name();
-  NoteData::TagMap & thetags(data_synchronizer().data().tags());
-  NoteData::TagMap::iterator iter;
+  auto & thetags(data_synchronizer().data().tags());
 
-  iter = thetags.find(tag_name);
-  if(iter == thetags.end())  {
-    return;
+  {
+    Tag::ORef iter;
+    auto t = thetags.find(tag_name);
+    if(t != thetags.end()) {
+      iter = manager().tag_manager().get_tag(*t);
+    }
+    if(!iter) {
+      return;
+    }
   }
 
   signal_tag_removing(*this, tag);
 
-  thetags.erase(iter);
+  thetags.erase(tag_name);
   tag.remove_note(*this);
 
   signal_tag_removed(*this, tag_name);
@@ -288,20 +296,11 @@ void NoteBase::remove_tag(Tag & tag)
   queue_save(OTHER_DATA_CHANGED);
 }
 
-void NoteBase::remove_tag(const Tag::Ptr & tag)
+bool NoteBase::contains_tag(const Tag &tag) const
 {
-  if(!tag)
-    throw sharp::Exception("Note.RemoveTag () called with a null tag.");
-  remove_tag(*tag);
-}
-
-bool NoteBase::contains_tag(const Tag::Ptr & tag) const
-{
-  if(!tag) {
-    return false;
-  }
-  const NoteData::TagMap & thetags(data_synchronizer().data().tags());
-  return (thetags.find(tag->normalized_name()) != thetags.end());
+  const auto tag_name = tag.normalized_name();
+  const auto &tags = data_synchronizer().data().tags();
+  return tags.find(tag_name) != tags.end();
 }
 
 Glib::ustring NoteBase::get_complete_note_xml()
@@ -340,7 +339,7 @@ void NoteBase::load_foreign_note_xml(const Glib::ustring & foreignNoteXml, Chang
 
   // Remove tags now, since a note with no tags has
   // no "tags" element in the XML
-  std::vector<Tag::Ptr> new_tags;
+  std::vector<Tag::Ref> new_tags;
   Glib::ustring name;
 
   while(xml.read()) {
@@ -367,8 +366,7 @@ void NoteBase::load_foreign_note_xml(const Glib::ustring & foreignNoteXml, Chang
         if(doc2) {
           std::vector<Glib::ustring> tag_strings = parse_tags(doc2->children);
           for(const Glib::ustring & tag_str : tag_strings) {
-            Tag::Ptr tag = m_manager.tag_manager().get_or_create_tag(tag_str);
-            new_tags.push_back(tag);
+            new_tags.emplace_back(m_manager.tag_manager().get_or_create_tag(tag_str));
           }
           xmlFreeDoc(doc2);
         }
@@ -384,24 +382,31 @@ void NoteBase::load_foreign_note_xml(const Glib::ustring & foreignNoteXml, Chang
 
   xml.close();
 
-  std::vector<Tag::Ptr> tag_list = get_tags();
+  auto tag_list = get_tags();
 
-  for(Tag::Ptr & iter : tag_list) {
-    if(std::find(new_tags.begin(), new_tags.end(), iter) == new_tags.end()) {
+  for(Tag &iter : tag_list) {
+    if(std::any_of(new_tags.begin(), new_tags.end(), [&iter](const Tag::Ref &tag) { return &iter == &tag.get(); })) {
       remove_tag(iter);
     }
   }
-  for(Tag::Ptr & iter : new_tags) {
-    add_tag(iter);
+  for(Tag &tag : new_tags) {
+    add_tag(tag);
   }
     
   // Allow method caller to specify ChangeType (mostly needed by sync)
   queue_save(changeType);
 }
 
-std::vector<Tag::Ptr> NoteBase::get_tags() const
+std::vector<Tag::Ref> NoteBase::get_tags() const
 {
-  return sharp::map_get_values(data_synchronizer().data().tags());
+  std::vector<Tag::Ref> ret;
+  for(const auto &tag_name : data_synchronizer().data().tags()) {
+    if(auto tag = manager().tag_manager().get_tag(tag_name)) {
+      ret.push_back(*tag);
+    }
+  }
+
+  return ret;
 }
 
 const NoteData & NoteBase::data() const
@@ -517,8 +522,8 @@ void NoteArchiver::_read(sharp::XmlReader & xml, NoteData & data, Glib::ustring
         if(doc2) {
           std::vector<Glib::ustring> tag_strings = NoteBase::parse_tags(doc2->children);
           for(const Glib::ustring & tag_str : tag_strings) {
-            Tag::Ptr tag = m_manager.tag_manager().get_or_create_tag(tag_str);
-            data.tags()[tag->normalized_name()] = tag;
+            Tag &tag = m_manager.tag_manager().get_or_create_tag(tag_str);
+            data.tags().insert(tag.normalized_name());
           }
           xmlFreeDoc(doc2);
         }
@@ -630,10 +635,9 @@ void NoteArchiver::write(sharp::XmlWriter & xml, const NoteData & data)
 
   if(data.tags().size() > 0) {
     xml.write_start_element("", "tags", "");
-    for(NoteData::TagMap::const_iterator iter = data.tags().begin();
-        iter != data.tags().end(); ++iter) {
+    for(const auto & tag_name : data.tags()) {
       xml.write_start_element("", "tag", "");
-      xml.write_string(iter->second->name());
+      xml.write_string(tag_name);
       xml.write_end_element();
     }
     xml.write_end_element();
