@@ -105,7 +105,7 @@ namespace gnote {
         // Make sure the template note has the notebook tag.
         // Since it's possible for the template note to already
         // exist, we need to make sure it gets tagged.
-        template_note.add_tag(notebook->get_tag());
+        template_note.add_tag(*notebook->get_tag());
         signal_note_added_to_notebook(template_note, *notebook);
 //      }
 
@@ -138,18 +138,17 @@ namespace gnote {
         return;
       }
 
-      Tag::Ptr tag = notebook.get_tag();
+      auto tag = notebook.get_tag();
       Notebook::Ptr keep_alive = *iter;
       m_all_notebooks.erase(iter);
 
       // Remove the notebook tag from every note that's in the notebook
-      std::vector<NoteBase*> notes;
       if(tag) {
-        notes = tag->get_notes();
-      }
-      for(NoteBase *note : notes) {
-        note->remove_tag(tag);
-        signal_note_removed_from_notebook(*static_cast<Note*>(note), notebook);
+        Tag &t = tag.value();
+        for(NoteBase *note : t.get_notes()) {
+          note->remove_tag(t);
+          signal_note_removed_from_notebook(*static_cast<Note*>(note), notebook);
+        }
       }
 
       signal_notebook_list_changed();
@@ -167,8 +166,7 @@ namespace gnote {
     /// </returns>
     Notebook::ORef NotebookManager::get_notebook_from_note(const NoteBase & note)
     {
-      std::vector<Tag::Ptr> tags = note.get_tags();
-      for(auto & tag : tags) {
+      for(Tag &tag : note.get_tags()) {
         if(auto notebook = get_notebook_from_tag(tag)) {
           return notebook;
         }
@@ -188,9 +186,9 @@ namespace gnote {
     /// <returns>
     /// A <see cref="Notebook"/>
     /// </returns>
-    Notebook::ORef NotebookManager::get_notebook_from_tag(const Tag::Ptr &tag)
+    Notebook::ORef NotebookManager::get_notebook_from_tag(const Tag &tag)
     {
-      if (!is_notebook_tag (tag)) {
+      if (!is_notebook_tag(tag)) {
         return Notebook::ORef();
       }
       
@@ -198,8 +196,7 @@ namespace gnote {
       // the name of the notebook and then look it up.
       Glib::ustring systemNotebookPrefix = Glib::ustring(Tag::SYSTEM_TAG_PREFIX)
         + Notebook::NOTEBOOK_TAG_PREFIX;
-      Glib::ustring notebookName = sharp::string_substring(tag->name(),
-                                                         systemNotebookPrefix.size());
+      Glib::ustring notebookName = sharp::string_substring(tag.name(), systemNotebookPrefix.size());
       
       return get_notebook(notebookName);
     }
@@ -215,9 +212,9 @@ namespace gnote {
     /// <returns>
     /// A <see cref="System.Boolean"/>
     /// </returns>
-    bool NotebookManager::is_notebook_tag(const Tag::Ptr & tag)
+    bool NotebookManager::is_notebook_tag(const Tag & tag)
     {
-      Glib::ustring fullTagName = tag->name();
+      Glib::ustring fullTagName = tag.name();
       return Glib::str_has_prefix(fullTagName,
                                   Glib::ustring(Tag::SYSTEM_TAG_PREFIX)
                                   + Notebook::NOTEBOOK_TAG_PREFIX);
@@ -345,15 +342,16 @@ namespace gnote {
 
       if(currentNotebook) {
         Notebook & nb = currentNotebook.value();
-        note.remove_tag(nb.get_tag());
+        note.remove_tag(*nb.get_tag());
         signal_note_removed_from_notebook(note, nb);
       }
 
       // Only attempt to add the notebook tag when this
       // menu item is not the "No notebook" menu item.
       if(notebook) {
-        note.add_tag(notebook.value().get().get_tag());
-        signal_note_added_to_notebook(note, notebook.value());
+        Notebook &nb = notebook.value();
+        note.add_tag(*nb.get_tag());
+        signal_note_added_to_notebook(note, nb);
       }
 
       return true;
@@ -366,12 +364,10 @@ namespace gnote {
     {
       Gtk::TreeIter<Gtk::TreeRow> iter;
       auto tags = m_note_manager.tag_manager().all_tags();
-      for(const auto & tag : tags) {
+      auto prefix = Glib::ustring(Tag::SYSTEM_TAG_PREFIX) + Notebook::NOTEBOOK_TAG_PREFIX;
+      for(const Tag &tag : tags) {
         // Skip over tags that aren't notebooks
-        if (!tag->is_system()
-            || !Glib::str_has_prefix(tag->name(),
-                                     Glib::ustring(Tag::SYSTEM_TAG_PREFIX)
-                                     + Notebook::NOTEBOOK_TAG_PREFIX)) {
+        if(!tag.is_system() || !Glib::str_has_prefix(tag.name(), prefix)) {
           continue;
         }
         Notebook::Ptr notebook = Notebook::create(m_note_manager, tag);
