@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017,2019-2020,2022-2023 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019-2020,2022-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -32,9 +32,9 @@ namespace gnote {
 namespace notebooks {
 
 
-Tag::Ptr SpecialNotebook::get_tag() const
+Tag::ORef SpecialNotebook::get_tag() const
 {
-  return Tag::Ptr();
+  return Tag::ORef();
 }
 
 Note & SpecialNotebook::get_template_note() const
@@ -201,11 +201,16 @@ bool ActiveNotesNotebook::empty()
   }
 
   // ignore template notes
-  Tag::Ptr templ_tag = template_tag();
+  auto templ_tag = template_tag();
+  if(!templ_tag) {
+    return false;
+  }
+  Tag &tag = templ_tag.value();
+
   for(const auto & note_uri : m_notes) {
     if(auto note_ref = m_note_manager.find_by_uri(note_uri)) {
       const NoteBase & note = note_ref.value();
-      if(!note.contains_tag(templ_tag)) {
+      if(!note.contains_tag(tag)) {
         return false;
       }
     }
