@@ -54,6 +54,7 @@ namespace gnote {
     bool is_first_run = NoteManagerBase::init(directory, backup);
 
     m_addin_mgr = create_addin_manager ();
+    NoteTagTable::setup_instance(m_preferences);
 
     if (is_first_run) {
       std::vector<ImportAddin*> l = m_addin_mgr->get_import_addins();
@@ -291,7 +292,7 @@ namespace gnote {
     // Copy template note's properties
     Glib::RefPtr<Gtk::TextBuffer> buffer = new_note.get_buffer();
     Gtk::TextIter cursor, selection;
-    Tag::Ptr template_save_selection = m_tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SELECTION_SYSTEM_TAG);
+    auto &template_save_selection = m_tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SELECTION_SYSTEM_TAG);
     if(template_note.contains_tag(template_save_selection)) {
       Glib::ustring template_title = template_note.get_title();
       int cursor_pos = template_note.data().cursor_position();
