@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2016-2017,2019-2023 Aurimas Cernius
+ * Copyright (C) 2010-2014,2016-2017,2019-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -247,7 +247,7 @@ NoteBase & NoteManagerBase::create(Glib::ustring && title, Glib::ustring && xml_
 // the template note.
 NoteBase & NoteManagerBase::create_note_from_template(Glib::ustring && title, const NoteBase & template_note, Glib::ustring && guid)
 {
-  Tag::Ptr template_save_title = tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_TITLE_SYSTEM_TAG);
+  auto &template_save_title = tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_TITLE_SYSTEM_TAG);
   if(template_note.contains_tag(template_save_title)) {
     title = get_unique_name(template_note.get_title());
   }
@@ -358,7 +358,7 @@ NoteBase & NoteManagerBase::get_or_create_template_note()
   auto & template_note = create(std::move(title), std::move(content));
 
   // Flag this as a template note
-  Tag::Ptr template_tag = tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+  auto &template_tag = tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
   template_note.add_tag(template_tag);
 
   template_note.queue_save(CONTENT_CHANGED);
@@ -405,8 +405,7 @@ Glib::ustring NoteManagerBase::make_new_file_name(const Glib::ustring & guid) co
 NoteBase::ORef NoteManagerBase::find_template_note() const
 {
   if(auto template_tag = tag_manager().get_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG)) {
-    auto notes = template_tag->get_notes();
-    for(NoteBase *iter : notes) {
+    for(NoteBase *iter : template_tag.value().get().get_notes()) {
       if(!m_gnote.notebook_manager().get_notebook_from_note(*iter)) {
         return std::ref(*iter);
       }
