@@ -31,6 +31,7 @@
 #include <gtkmm/texttag.h>
 #include <gtkmm/texttagtable.h>
 
+#include "preferences.hpp"
 #include "tag.hpp"
 #include "sharp/exception.hpp"
 
@@ -250,13 +251,16 @@ public:
   typedef Glib::RefPtr<NoteTagTable> Ptr;
   typedef sigc::slot<DynamicNoteTag::Ptr()> Factory;
 
-  static const char *HIGHLIGHT_COLOR;
-  static const char *HIGHLIGHT_TEXT_COLOR;
-
-  static const NoteTagTable::Ptr & instance() 
+  static void setup_instance(Preferences &prefs)
     {
       if(!s_instance) {
-        s_instance = NoteTagTable::Ptr(new NoteTagTable);
+        s_instance = NoteTagTable::Ptr(new NoteTagTable(prefs));
+      }
+    }
+  static const NoteTagTable::Ptr & instance()
+    {
+      if(!s_instance) {
+        throw sharp::Exception("NoteTagTable not set up");
       }
       return s_instance;
     }
@@ -294,15 +298,19 @@ public:
       return m_broken_link_tag;
     }
 protected:
-  NoteTagTable()
+  NoteTagTable(Preferences &prefs)
+    : m_preferences(prefs)
     {
       _init_common_tags();
     }
 
 private:
   void _init_common_tags();
+  void on_highlight_background_setting_changed();
+  void on_highlight_foreground_setting_changed();
 
   static NoteTagTable::Ptr           s_instance;
+  Preferences &m_preferences;
   std::map<Glib::ustring, Factory>   m_tag_types;
 
   NoteTag::Ptr m_url_tag;
