@@ -58,9 +58,9 @@ namespace gnote {
     , m_enabled(true)
   {
     ITagManager & tag_manager = note.manager().tag_manager();
-    m_template_tag = tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
-    m_template_save_selection_tag = tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SELECTION_SYSTEM_TAG);
-    m_template_save_title_tag = tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_TITLE_SYSTEM_TAG);
+    m_template_tag = tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG).normalized_name();
+    m_template_save_selection_tag = tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SELECTION_SYSTEM_TAG).normalized_name();
+    m_template_save_title_tag = tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_TITLE_SYSTEM_TAG).normalized_name();
 
     set_hexpand(true);
     set_vexpand(true);
@@ -392,11 +392,11 @@ namespace gnote {
     untemplateButton->signal_clicked().connect(sigc::mem_fun(*this, &NoteWindow::on_untemplate_button_click));
 
     m_save_selection_check_button = manage(new Gtk::CheckButton(_("Save Se_lection"), true));
-    m_save_selection_check_button->set_active(m_note.contains_tag(m_template_save_selection_tag));
+    m_save_selection_check_button->set_active(m_note.contains_tag(template_save_selection_tag()));
     m_save_selection_check_button->signal_toggled().connect(sigc::mem_fun(*this, &NoteWindow::on_save_selection_check_button_toggled));
 
     m_save_title_check_button = manage(new Gtk::CheckButton(_("Save _Title"), true));
-    m_save_title_check_button->set_active(m_note.contains_tag(m_template_save_title_tag));
+    m_save_title_check_button->set_active(m_note.contains_tag(template_save_title_tag()));
     m_save_title_check_button->signal_toggled().connect(sigc::mem_fun(*this, &NoteWindow::on_save_title_check_button_toggled));
 
     bar->attach(*infoLabel, 0, 0, 1, 1);
@@ -404,8 +404,10 @@ namespace gnote {
     bar->attach(*m_save_selection_check_button, 0, 2, 1, 1);
     bar->attach(*m_save_title_check_button, 0, 3, 1, 1);
 
-    if(!m_note.contains_tag(m_template_tag)) {
-      bar->hide();
+    if(auto template_tag = m_note.manager().tag_manager().get_tag(m_template_tag)) {
+      if(!m_note.contains_tag(*template_tag)) {
+        bar->hide();
+      }
     }
 
     m_note.signal_tag_added.connect(sigc::mem_fun(*this, &NoteWindow::on_note_tag_added));
@@ -417,17 +419,19 @@ namespace gnote {
 
   void NoteWindow::on_untemplate_button_click()
   {
-    m_note.remove_tag(m_template_tag);
+    if(auto template_tag = m_note.manager().tag_manager().get_tag(m_template_tag)) {
+      m_note.remove_tag(*template_tag);
+    }
   }
 
 
   void NoteWindow::on_save_selection_check_button_toggled()
   {
     if(m_save_selection_check_button->get_active()) {
-      m_note.add_tag(m_template_save_selection_tag);
+      m_note.add_tag(template_save_selection_tag());
     }
     else {
-      m_note.remove_tag(m_template_save_selection_tag);
+      m_note.remove_tag(template_save_selection_tag());
     }
   }
 
@@ -435,17 +439,17 @@ namespace gnote {
   void NoteWindow::on_save_title_check_button_toggled()
   {
     if(m_save_title_check_button->get_active()) {
-      m_note.add_tag(m_template_save_title_tag);
+      m_note.add_tag(template_save_title_tag());
     }
     else {
-      m_note.remove_tag(m_template_save_title_tag);
+      m_note.remove_tag(template_save_title_tag());
     }
   }
 
 
-  void NoteWindow::on_note_tag_added(const NoteBase&, const Tag::Ptr & tag)
+  void NoteWindow::on_note_tag_added(const NoteBase&, const Tag &tag)
   {
-    if(tag == m_template_tag) {
+    if(tag.normalized_name() == m_template_tag) {
       m_template_widget->show();
     }
   }
@@ -453,7 +457,7 @@ namespace gnote {
 
   void NoteWindow::on_note_tag_removed(const NoteBase&, const Glib::ustring & tag)
   {
-    if(tag == m_template_tag->normalized_name()) {
+    if(tag == m_template_tag) {
       m_template_widget->hide();
     }
   }
@@ -539,7 +543,7 @@ namespace gnote {
 
   void NoteWindow::on_text_button_clicked(Gtk::Widget *parent)
   {
-    auto text_menu = Gtk::make_managed<NoteTextMenu>(*this, m_note.get_buffer());
+    auto text_menu = Gtk::make_managed<NoteTextMenu>(*this, m_note.get_buffer(), m_gnote.preferences());
     text_menu->set_parent(*parent);
     utils::unparent_popover_on_close(text_menu);
     signal_build_text_menu(*text_menu);
@@ -741,6 +745,24 @@ namespace gnote {
     host->find_action("redo")->property_enabled() = undo_manager.get_can_redo();
   }
 
+  Tag &NoteWindow::template_save_selection_tag()
+  {
+    if(auto tag = m_note.manager().tag_manager().get_tag(m_template_save_selection_tag)) {
+      return *tag;
+    }
+
+    throw std::runtime_error("No save selection tag found");
+  }
+
+  Tag &NoteWindow::template_save_title_tag()
+  {
+    if(auto tag = m_note.manager().tag_manager().get_tag(m_template_save_title_tag)) {
+      return *tag;
+    }
+
+    throw std::runtime_error("No save title tag found");
+  }
+
 
   NoteFindHandler::NoteFindHandler(Note & note)
     : m_note(note)
@@ -935,7 +957,7 @@ namespace gnote {
   // Menu for font style and size, and set the active radio
   // menuitem depending on the cursor poition.
   //
-  NoteTextMenu::NoteTextMenu(EmbeddableWidget & widget, const Glib::RefPtr<NoteBuffer> & buffer)
+  NoteTextMenu::NoteTextMenu(EmbeddableWidget & widget, const Glib::RefPtr<NoteBuffer> & buffer, Preferences &prefs)
     : Gtk::Popover()
     {
       set_position(Gtk::PositionType::BOTTOM);
@@ -955,7 +977,7 @@ namespace gnote {
       highlight->set_has_frame(false);
       auto label = Gtk::make_managed<Gtk::Label>();
       Glib::ustring markup = Glib::ustring::compose("<span color=\"%1\" background=\"%2\">%3</span>",
-        NoteTagTable::HIGHLIGHT_TEXT_COLOR, NoteTagTable::HIGHLIGHT_COLOR, _("_Highlight"));
+        prefs.highlight_foreground_color(), prefs.highlight_background_color(), _("_Highlight"));
       label->set_markup_with_mnemonic(markup);
       highlight->set_child(*label);
 
