@@ -78,6 +78,8 @@ const Glib::ustring ENABLE_AUTO_LINKS = "enable-auto-links";
 const Glib::ustring ENABLE_URL_LINKS = "enable-url-links";
 const Glib::ustring ENABLE_WIKIWORDS = "enable-wikiwords";
 const Glib::ustring ENABLE_CUSTOM_FONT = "enable-custom-font";
+const Glib::ustring HIGHLIGH_BACKGROUND_COLOR = "highlight-background-color";
+const Glib::ustring HIGHLIGH_FOREGROUND_COLOR = "highlight-foreground-color";
 const Glib::ustring ENABLE_AUTO_BULLETED_LISTS = "enable-bulleted-lists";
 //const Glib::ustring ENABLE_ICON_PASTE = "enable-icon-paste";  NOT USED CURRENTLY
 const Glib::ustring ENABLE_CLOSE_NOTE_ON_ESCAPE = "enable-close-note-on-escape";
@@ -128,6 +130,8 @@ namespace gnote {
     SETUP_CACHED_KEY(m_schema_gnote, enable_url_links, ENABLE_URL_LINKS, boolean);
     SETUP_CACHED_KEY(m_schema_gnote, enable_wikiwords, ENABLE_WIKIWORDS, boolean);
     SETUP_CACHED_KEY(m_schema_gnote, enable_custom_font, ENABLE_CUSTOM_FONT, boolean);
+    SETUP_CACHED_KEY(m_schema_gnote, highlight_background_color, HIGHLIGH_BACKGROUND_COLOR, string);
+    SETUP_CACHED_KEY(m_schema_gnote, highlight_foreground_color, HIGHLIGH_FOREGROUND_COLOR, string);
     SETUP_CACHED_KEY(m_schema_gnote, note_rename_behavior, NOTE_RENAME_BEHAVIOR, int);
     SETUP_CACHED_KEY(m_schema_gnote, custom_font_face, CUSTOM_FONT_FACE, string);
     SETUP_CACHED_KEY(m_schema_gnote, color_scheme, COLOR_SCHEME, string);
@@ -143,6 +147,8 @@ namespace gnote {
   DEFINE_CACHING_SETTER_BOOL(m_schema_gnote, enable_url_links, ENABLE_URL_LINKS)
   DEFINE_CACHING_SETTER_BOOL(m_schema_gnote, enable_wikiwords, ENABLE_WIKIWORDS)
   DEFINE_CACHING_SETTER_BOOL(m_schema_gnote, enable_custom_font, ENABLE_CUSTOM_FONT)
+  DEFINE_CACHING_SETTER_STRING(m_schema_gnote, highlight_background_color, HIGHLIGH_BACKGROUND_COLOR)
+  DEFINE_CACHING_SETTER_STRING(m_schema_gnote, highlight_foreground_color, HIGHLIGH_FOREGROUND_COLOR)
   DEFINE_GETTER_SETTER_BOOL(m_schema_gnote, enable_auto_bulleted_lists, ENABLE_AUTO_BULLETED_LISTS)
   DEFINE_CACHING_SETTER_INT(m_schema_gnote, note_rename_behavior, NOTE_RENAME_BEHAVIOR)
   DEFINE_GETTER_SETTER_STRING(m_schema_gnote, start_note_uri, START_NOTE_URI)
