@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2017,2019-2023 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019-2024 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -63,11 +63,11 @@ public:
   virtual MainWindowAction::Ptr find_action(const Glib::ustring & name) override;
   virtual void enabled(bool is_enabled) override;
 protected:
-  virtual void present_note(const Note::Ptr & note) override;
+  void present_note(Note & note) override;
   virtual void on_show() override;
   virtual void on_map() override;
 private:
-  void on_open_note_new_window(const Note::Ptr &);
+  void on_open_note_new_window(Note &);
   bool on_close();
   bool on_key_pressed(guint keyval, guint keycode, Gdk::ModifierType state);
   EmbeddableWidget *currently_foreground();
@@ -76,8 +76,11 @@ private:
   void add_shortcut(Gtk::Widget & widget, guint keyval, Gdk::ModifierType modifiers = static_cast<Gdk::ModifierType>(0));
   void add_shortcut(Gtk::ShortcutController & controller, guint keyval, Gdk::ModifierType modifiers = static_cast<Gdk::ModifierType>(0));
   void make_header_bar();
-  void make_search_box();
-  void make_find_next_prev();
+  bool make_search_box();
+  void make_find_next_prev(Gtk::Button *&find_next, Gtk::Button *&find_prev);
+  void show_find_next_prev();
+  void hide_find_next_prev();
+  bool get_find_next_prev(Gtk::Button *&find_next, Gtk::Button *&find_prev) const;
   bool on_entry_key_pressed(guint keyval, guint keycode, Gdk::ModifierType state);
   void on_search_changed();
   void on_search_stopped();
@@ -94,7 +97,7 @@ private:
   bool on_notes_widget_key_press(guint keyval, guint keycode, Gdk::ModifierType state);
   void on_close_window(const Glib::VariantBase&);
   void add_action(const MainWindowAction::Ptr & action);
-  bool present_active(const Note::Ptr & note);
+  bool present_active(Note & note);
   void register_actions();
   void callbacks_changed();
   void register_callbacks();
@@ -108,8 +111,7 @@ private:
   Preferences        &m_preferences;
   Gtk::Widget        *m_header_bar;
   SearchNotesWidget  *m_search_notes_widget;
-  Gtk::Grid          *m_search_box;
-  Gtk::Grid          *m_find_next_prev_box;
+  Gtk::Box *m_search_box;
   union
   {
     Gtk::SearchEntry *m_search_entry;
