@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2015,2017,2019-2024 Aurimas Cernius
+ * Copyright (C) 2010-2015,2017,2019-2025 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -262,7 +262,8 @@ private:
 
 
 SearchNotesWidget::SearchNotesWidget(IGnote & g, NoteManagerBase & m)
-  : m_gnote(g)
+  : m_notes_pane(Gtk::Orientation::VERTICAL)
+  , m_gnote(g)
   , m_manager(m)
   , m_clickX(0), m_clickY(0)
   , m_matches_column(NULL)
@@ -277,13 +278,29 @@ SearchNotesWidget::SearchNotesWidget(IGnote & g, NoteManagerBase & m)
 
   set_position(150);
   set_start_child(*notebooksPane);
-  set_end_child(m_matches_window);
+  m_notes_pane.append(m_matches_window);
+  auto actions = Gtk::make_managed<Gtk::Box>();
+  auto new_note_button = Gtk::make_managed<Gtk::Button>();
+  new_note_button->set_icon_name("list-add-symbolic");
+  new_note_button->set_tooltip_text(_("New Note"));
+  new_note_button->set_has_frame(false);
+  new_note_button->signal_clicked().connect(sigc::mem_fun(*this, &SearchNotesWidget::new_note));
+  m_delete_note_button.set_icon_name("edit-delete-symbolic");
+  m_delete_note_button.set_tooltip_text(_("Delete Note"));
+  m_delete_note_button.set_has_frame(false);
+  m_delete_note_button.signal_clicked().connect(sigc::mem_fun(*this, &SearchNotesWidget::delete_selected_notes));
+  actions->append(*new_note_button);
+  actions->append(m_delete_note_button);
+  m_notes_pane.append(*actions);
+  set_end_child(m_notes_pane);
 
   make_recent_notes_view();
 
   m_matches_window.property_hscrollbar_policy() = Gtk::PolicyType::AUTOMATIC;
   m_matches_window.property_vscrollbar_policy() = Gtk::PolicyType::AUTOMATIC;
   m_matches_window.set_child(*m_notes_view);
+  m_matches_window.set_expand(true);
+
 
   // Update on changes to notes
   m.signal_note_deleted.connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_deleted));
@@ -381,7 +398,7 @@ void SearchNotesWidget::perform_search()
 void SearchNotesWidget::restore_matches_window()
 {
   if(m_no_matches_box && get_end_child() == m_no_matches_box.get()) {
-    set_end_child(m_matches_window);
+    set_end_child(m_notes_pane);
   }
 }
 
@@ -421,19 +438,6 @@ void SearchNotesWidget::save_position()
   m_gnote.preferences().search_window_height(height);
 }
 
-void SearchNotesWidget::rename_notebook(const notebooks::Notebook& old_notebook, const Glib::ustring& new_name)
-{
-  notebooks::NotebookManager & notebook_manager = m_gnote.notebook_manager();
-  auto & new_notebook = notebook_manager.get_or_create_notebook(new_name);
-  DBG_OUT("Renaming notebook '{%s}' to '{%s}'", old_notebook.get_name().c_str(), new_name.c_str());
-  auto notes = old_notebook.get_tag()->get_notes();
-  for(NoteBase *note : notes) {
-    notebook_manager.move_note_to_notebook(static_cast<Note&>(*note), new_notebook);
-  }
-  notebook_manager.delete_notebook(const_cast<notebooks::Notebook&>(old_notebook));
-  m_notebooks_view->select_notebook(new_notebook);
-}
-
 void SearchNotesWidget::on_notebook_selection_changed(const notebooks::Notebook & notebook)
 {
   restore_matches_window();
@@ -494,46 +498,6 @@ std::vector<Note::Ref> SearchNotesWidget::get_selected_notes()
   return selected_notes;
 }
 
-bool SearchNotesWidget::filter_notes(const Gtk::TreeIter<Gtk::TreeConstRow> & iter)
-{
-  Note::Ptr note = (*iter)[m_column_types.note];
-  if(!note) {
-    return false;
-  }
-
-  auto selected_notebook = m_notebooks_view->get_selected_notebook();
-  if(!selected_notebook || !selected_notebook.value().get().contains_note(*note)) {
-    return false;
-  }
-
-  bool passes_search_filter = filter_by_search(*note);
-  if(passes_search_filter == false) {
-    return false; // don't waste time checking tags if it's already false
-  }
-
-  bool passes_tag_filter = true; // no selected notebook
-  if(auto notebook = m_notebooks_view->get_selected_notebook()) {
-    if(auto tag = notebook.value().get().get_tag()) {
-      passes_tag_filter = filter_by_tag(*note, tag);
-    }
-  }
-
-  // Must pass both filters to appear in the list
-  return passes_tag_filter && passes_search_filter;
-}
-
-int SearchNotesWidget::compare_titles(const Gtk::TreeIter<Gtk::TreeConstRow> & a, const Gtk::TreeIter<Gtk::TreeConstRow> & b)
-{
-  Glib::ustring title_a = (*a)[m_column_types.title];
-  Glib::ustring title_b = (*b)[m_column_types.title];
-
-  if(title_a.empty() || title_b.empty()) {
-    return -1;
-  }
-
-  return title_a.lowercase().compare(title_b.lowercase());
-}
-
 void SearchNotesWidget::make_recent_notes_view()
 {
   m_notes_view = Gtk::make_managed<Gtk::ColumnView>();
@@ -626,17 +590,6 @@ bool SearchNotesWidget::filter_by_search(const Note & note)
   return m_current_matches.find(note.uri()) != m_current_matches.end();
 }
 
-bool SearchNotesWidget::filter_by_tag(const Note & note, const Tag::Ptr & tag)
-{
-  for(auto & t : note.get_tags()) {
-    if(tag == t) {
-      return true;
-    }
-  }
-
-  return false;
-}
-
 void SearchNotesWidget::on_row_activated(guint idx)
 {
   auto selected_notes = get_selected_notes();
@@ -660,6 +613,7 @@ void SearchNotesWidget::on_selection_changed(guint, guint)
     }
     if(auto action = win->find_action("delete-selected-notes")) {
       action->set_enabled(enabled);
+      m_delete_note_button.set_sensitive(enabled);
     }
   }
 }
