@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017,2019-2020 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017,2019-2020,2023 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,13 +63,13 @@ namespace sync {
   }
 
 
-  void GnoteSyncClient::note_deleted_handler(const NoteBase::Ptr & deletedNote)
+  void GnoteSyncClient::note_deleted_handler(NoteBase & deleted_note)
   {
     if(m_synchronizing) {
       return;
     }
-    m_deleted_notes[deletedNote->id()] = deletedNote->get_title();
-    m_file_revisions.erase(deletedNote->id());
+    m_deleted_notes[deleted_note.id()] = deleted_note.get_title();
+    m_file_revisions.erase(deleted_note.id());
 
     write(m_local_manifest_file_path);
   }
@@ -249,9 +249,9 @@ namespace sync {
   }
 
 
-  int GnoteSyncClient::get_revision(const NoteBase::Ptr & note)
+  int GnoteSyncClient::get_revision(const NoteBase & note)
   {
-    Glib::ustring note_guid = note->id();
+    Glib::ustring note_guid = note.id();
     auto iter = m_file_revisions.find(note_guid);
     if(iter != m_file_revisions.end()) {
       return iter->second;
@@ -262,9 +262,9 @@ namespace sync {
   }
 
 
-  void GnoteSyncClient::set_revision(const NoteBase::Ptr & note, int revision)
+  void GnoteSyncClient::set_revision(const NoteBase & note, int revision)
   {
-    m_file_revisions[note->id()] = revision;
+    m_file_revisions[note.id()] = revision;
   }
 
 
