@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017,2019 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017,2019,2023 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,14 +74,14 @@ namespace sync {
   }
 
 
-  void SilentUI::note_conflict_detected(const Note::Ptr & localConflictNote,
+  void SilentUI::note_conflict_detected(NoteBase & localConflictNote,
                                         NoteUpdate remoteNote,
                                         const std::vector<Glib::ustring> &)
   {
     DBG_OUT("note conflict detected, overwriting without a care");
     // TODO: At least respect conflict prefs
     // TODO: Implement more useful conflict handling
-    if(localConflictNote->id() != remoteNote.m_uuid) {
+    if(localConflictNote.id() != remoteNote.m_uuid) {
       m_manager.delete_note(localConflictNote);
     }
     m_gnote.sync_manager().resolve_conflict(OVERWRITE_EXISTING);
@@ -96,18 +96,18 @@ namespace sync {
   void SilentUI::on_connecting()
   {
     m_manager.read_only(true);
-    for(const NoteBase::Ptr & iter : m_manager.get_notes()) {
-      iter->enabled(false);
-    }
+    m_manager.for_each([](NoteBase & note) {
+      note.enabled(false);
+    });
   }
 
 
   void SilentUI::on_idle()
   {
     m_manager.read_only(false);
-    for(const NoteBase::Ptr & iter : m_manager.get_notes()) {
-      iter->enabled(true);
-    }
+    m_manager.for_each([](NoteBase & note) {
+      note.enabled(true);
+    });
     m_ui_disabled = false;
   }
 
