@@ -49,7 +49,7 @@ namespace sync {
     SyncDialog(IGnote &, NoteManagerBase &);
     virtual void sync_state_changed(SyncState state) override;
     virtual void note_synchronized(const Glib::ustring & noteTitle, NoteSyncType type) override;
-    virtual void note_conflict_detected(const Note::Ptr & localConflictNote,
+    virtual void note_conflict_detected(NoteBase & localConflictNote,
                                         NoteUpdate remoteNote,
                                         const std::vector<Glib::ustring> & noteUpdateTitles) override;
     virtual void present_ui() override;
@@ -62,7 +62,7 @@ namespace sync {
     virtual void on_realize() override;
   private:
     static void on_expander_activated(GtkExpander*, gpointer);
-    void note_conflict_detected_(const Note::Ptr & localConflictNote,
+    void note_conflict_detected_(Note & localConflictNote,
                                  NoteUpdate remoteNote,
                                  const std::vector<Glib::ustring> & noteUpdateTitles,
                                  SyncTitleConflictResolution savedBehavior,
@@ -72,7 +72,7 @@ namespace sync {
                                  bool & completed);
     void conflict_dialog_response(
       Gtk::Dialog *dialog,
-      const Note::Ptr & localConflictNote,
+      const Glib::ustring & localConflictNote,
       NoteUpdate remoteNote,
       SyncTitleConflictResolution savedBehavior,
       SyncTitleConflictResolution resolution,
@@ -82,8 +82,8 @@ namespace sync {
     bool on_pulse_progress_bar();
     void on_row_activated(guint idx);
     void sync_state_changed_(SyncState state);
-    void rename_note(const Note::Ptr & note, Glib::ustring && newTitle, bool updateReferencingNotes);
-    void present_note(const Note::Ptr &);
+    void rename_note(const Glib::ustring & note_uri, Glib::ustring && newTitle, bool updateReferencingNotes);
+    void present_note(Note &);
 
     Gtk::Image *m_image;
     Gtk::Label *m_header_label;
