@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017,2019-2023 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017,2019-2024 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,10 +44,16 @@ namespace sync {
     : m_gnote(g)
     , m_note_manager(m)
     , m_state(IDLE)
-    , m_sync_thread(NULL)
   {
   }
 
+  SyncManager::~SyncManager()
+  {
+    if (m_sync_checker_thread) {
+      m_sync_checker_thread->join();
+      m_sync_checker_thread.reset();
+    }
+  }
 
   void SyncManager::init()
   {
@@ -109,7 +115,7 @@ namespace sync {
 
   void SyncManager::perform_synchronization(const SyncUI::Ptr & sync_ui)
   {
-    if(m_sync_thread != NULL) {
+    if(m_sync_thread) {
       // A synchronization thread is already running
       // TODO: Start new sync if existing dlg is for finished sync
       DBG_OUT("A synchronization thread is already running");
@@ -119,7 +125,7 @@ namespace sync {
 
     m_sync_ui = sync_ui;
     DBG_OUT("Creating synchronization thread");
-    m_sync_thread = new std::thread([this] { synchronization_thread(); });
+    m_sync_thread.reset(new std::thread([this] { synchronization_thread(); }));
     m_sync_thread->detach();
   }
 
@@ -132,7 +138,6 @@ namespace sync {
       finally(SyncManager & m) : manager(m), addin(NULL){}
       ~finally()
       {
-        manager.m_sync_thread = NULL;
         try {
           if(addin) {
             addin->post_sync_cleanup();
@@ -141,6 +146,8 @@ namespace sync {
         catch(std::exception & e) {
           ERR_OUT(_("Error cleaning up addin after synchronization: %s"), e.what());
         }
+        auto &m = manager;
+        utils::main_context_invoke([&m] { m.m_sync_thread.reset(); });
       }
     } f(*this);
     std::unique_ptr<SyncServer> server;
@@ -150,7 +157,6 @@ namespace sync {
         set_state(NO_CONFIGURED_SYNC_SERVICE);
         DBG_OUT("GetConfiguredSyncService is null");
         set_state(IDLE);
-        m_sync_thread = NULL;
         return;
       }
 
@@ -166,7 +172,6 @@ namespace sync {
         set_state(SYNC_SERVER_CREATION_FAILED);
         ERR_OUT(_("Exception while creating SyncServer: %s"), e.what());
         set_state(IDLE);
-        m_sync_thread = NULL;
         f.addin->post_sync_cleanup();// TODO: Needed?
         return;
         // TODO: Figure out a clever way to get the specific error up to the GUI
@@ -181,7 +186,6 @@ namespace sync {
         set_state(LOCKED);
         DBG_OUT("Server locked, try again later");
         set_state(IDLE);
-        m_sync_thread = NULL;
         f.addin->post_sync_cleanup();
         return;
       }
@@ -406,7 +410,7 @@ namespace sync {
     // Note changed, iff a sync is coming up we kill the
     // timer to avoid interupting the user (we want to
     // make sure not to sync more often than the user's pref)
-    if(m_sync_thread == NULL) {
+    if(!m_sync_thread) {
       Glib::TimeSpan time_since_last_check = Glib::DateTime::create_now_utc().difference(m_last_background_check);
       if(sharp::time_span_total_minutes(time_since_last_check) > m_autosync_timeout_pref_minutes - 1) {
         DBG_OUT("Note edited...killing autosync timer until next save or delete event");
@@ -439,7 +443,7 @@ namespace sync {
 
   void SyncManager::handle_note_saved_or_deleted(NoteBase &)
   {
-    if(m_sync_thread == NULL && m_autosync_timeout_pref_minutes > 0) {
+    if(!m_sync_thread && m_autosync_timeout_pref_minutes > 0) {
       DBG_OUT("Note saved or deleted...restarting sync timer");
       m_last_background_check = Glib::DateTime::create_now_utc();
       // Perform a sync one minute after setting change
@@ -449,11 +453,14 @@ namespace sync {
   }
 
 
-  void SyncManager::background_sync_checker()
+  void SyncManager::sync_checker_thread()
   {
+    bool need_update = false;
+
     m_last_background_check = Glib::DateTime::create_now_utc();
     m_current_autosync_timeout_minutes = m_autosync_timeout_pref_minutes;
-    if(m_sync_thread != NULL) {
+    if(m_sync_thread) {
+      utils::main_context_invoke([this, need_update]() { on_sync_checker_finished(need_update); });
       return;
     }
     SyncServiceAddin *addin = get_configured_sync_service();
@@ -469,6 +476,7 @@ namespace sync {
       catch(std::exception & e) {
         DBG_OUT("Exception while creating SyncServer: %s\n", e.what());
         addin->post_sync_cleanup();// TODO: Needed?
+        utils::main_context_invoke([this, need_update]() { on_sync_checker_finished(need_update); });
         return;
         // TODO: Figure out a clever way to get the specific error up to the GUI
       }
@@ -494,6 +502,7 @@ namespace sync {
         // TODO: A libnotify bubble might be nice
         DBG_OUT("Error connecting to server");
         addin->post_sync_cleanup();
+        utils::main_context_invoke([this, need_update]() { on_sync_checker_finished(need_update); });
         return;
       }
 
@@ -502,14 +511,41 @@ namespace sync {
       if(client_has_updates || server_has_updates) {
         DBG_OUT("Detected that sync would be a good idea now");
         // TODO: Check that it's safe to sync, block other sync UIs
-        perform_synchronization(SilentUI::create(m_gnote, note_mgr()));
+	need_update = true;
       }
     }
 
+    utils::main_context_invoke([this, need_update]() { on_sync_checker_finished(need_update); });
+
     return;
   }
 
 
+  void SyncManager::on_sync_checker_finished(bool need_update)
+  {
+    if (m_sync_checker_thread) {
+      m_sync_checker_thread->join();
+      m_sync_checker_thread.reset();
+    }
+
+    if (need_update) {
+      perform_synchronization(SilentUI::create(m_gnote, note_mgr()));
+    }
+  }
+
+
+  void SyncManager::background_sync_checker()
+  {
+    if(m_sync_checker_thread) {
+      // A synchronization checker thread is already running
+      DBG_OUT("A sync checker thread is already running");
+      return;
+    }
+
+    DBG_OUT("Creating sync checker thread");
+    m_sync_checker_thread.reset(new std::thread([this] { sync_checker_thread(); }));
+  }
+
   void SyncManager::set_state(SyncState new_state)
   {
     m_state = new_state;
